<template>
  <!-- 产品详情 -->
  <div class="bbsl-common-page">
    <div class="bbsl-table-search">
      <el-page-header @back="goBack" :content="this.$route.query.name">
      </el-page-header>
    </div>
    <div class="bbsl-table-content" ref="contentPanel">
      <div class="bbsl-btn-content" ref="btnPanel"></div>
      <el-tabs v-model="activeName" @tab-click="handleClick">
        <el-tab-pane label="产品信息" name="first">
          <div class="title-box">
            <span class="title">基础信息</span>
            <div @click="alterBasis">
              <i class="el-icon-edit bule" style="margin-left: 10px;"></i>
              <span class="bule">修改</span>
            </div>
          </div>
          <div>
            <el-descriptions class="margin-top" :column="3" :size="size" border>
              <el-descriptions-item>
                <template slot="label">
                  产品编码
                </template>
                {{ this.parameter.code }}
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label">
                  产品名称
                </template>
                {{ this.parameter.name }}
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label">
                  设备类型
                </template>
                {{ this.deviceTypeName }}
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label">
                  智能分类
                </template>
                {{ this.isIntellectName }}
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label">
                  所属分类
                </template>
                {{ this.fullName }}
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label">
                  发布状态
                </template>
                {{ this.parameter.publishStatus == 1 ? '已发布' : '未发布' }}
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label">
                  图标
                </template>
                <svgIcon icon-style="icon" v-if="parameter.icon" :icon-class="parameter.icon"
                  style="font-size: 24px; vertical-align: middle;margin-right: 10px; " />
                <!-- <img v-if="parameter.icon" class="icon" :src="previewUrl + this.parameter.icon"
                  alt="" /> -->
              </el-descriptions-item>
              <el-descriptions-item>
                <template slot="label">
                  备注
                </template>
                {{ this.parameter.memo }}
              </el-descriptions-item>
            </el-descriptions>
          </div>
        </el-tab-pane>
        <el-tab-pane label="扩展信息" name="second" :lazy="true">
          <productExtendDialog v-if="activeName == 'second'" :parameter="parameter"></productExtendDialog>
        </el-tab-pane>
        <el-tab-pane label="告警数据模型" name="third" :lazy="true">
          <ProductPhysicalModel v-if="activeName == 'third'" :parameter="parameter"></ProductPhysicalModel>
        </el-tab-pane>
        <el-tab-pane label="告警设置" name="fourth" :lazy="true">
          <AlarmConfiguration v-if="activeName == 'fourth'" :parameter="parameter"></AlarmConfiguration>
        </el-tab-pane>
      </el-tabs>
    </div>
    <BasicInformationDialog ref="formModal" :parameter="parameter" @loadData="loadData"></BasicInformationDialog>
  </div>
</template>

<script>
import {
  TableMixin
} from '@/mixins/tableMixin'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import ProductPhysicalModel from './modle/ProductPhysicalModel.vue'
import AlarmConfiguration from './modle/AlarmConfiguration.vue'
import BasicInformationDialog from './modle/BasicInformationDialog.vue'
import productExtendDialog from '@/views/Device/deviceManage/components/productExtendDialog'
import productManage from '@/api/device/productManage.js'

export default {
  name: 'EquipmentDetails',
  components: {
    ProductPhysicalModel,
    BasicInformationDialog,
    productExtendDialog,
    AlarmConfiguration
  },
  mixins: [TableMixin],
  data() {
    return {
      productId: '',
      activeName: 'first',
      parameter: {}, //接收参数
      size: '',
      fullName: '',
      deviceTypeList: [],
      ctlTypeList: [],
      isIntellectList: [],
      deviceTypeName: '',
      isIntellectName: '',
      previewUrl: window.context.portal + '/file/onlinePreviewController/v1/getFileById_' //图标预览
    }
  },
  created() {
    this.productId = this.$route.query.id
    this.deviceTypeList = dictUtils.getDictItemsFromCache('sblx')
    this.ctlTypeList = dictUtils.getDictItemsFromCache('kjlx') //
    this.isIntellectList = dictUtils.getDictItemsFromCache('znfl') //智能分类
    this.loadData()
  },
  mounted() {
    // this.parameter = this.$route.query
  },
  methods: {
    handleClick(tab, event) {
    },
    goBack() {
      this.$router.go(-1)
    },
    alterBasis() {
      this.$refs.formModal.add()
    },
    loadData(page) {
      productManage.productInfoDetail(this.productId).then(res => {
        this.parameter = res
        this.deviceTypeList.forEach(e => {
          if (e.value == this.parameter.deviceType) {
            this.deviceTypeName = e.name
          }
        })
        this.isIntellectList.forEach(s => {
          if (s.value == this.parameter.isIntellect) {
            this.isIntellectName = s.name
          }
        })
        productManage.productTypeDetail(this.parameter.typeId).then(res => {
          this.fullName = res.name
        })
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}

.header-left {
  margin-top: 10px;
}

.title-box {
  display: flex;
  padding: 10px 0;

  .title {
    font-weight: 600;
  }

  .bule {
    color: #1289fd;
  }

  .bule:hover {
    cursor: pointer;
  }
}

::v-deep .el-descriptions-item__cell {
  width: 17%;
}

::v-deep .el-descriptions-item__label.is-bordered-label {
  color: #606266;
}

::v-deep .el-tab-pane {
  height: calc(100% - 70px);
  overflow-y: auto;
  overflow-x: hidden;
}

::v-deep .icon {
  width: 16px;
  height: 16px;
}

// ::v-deep * {
//   font-size: 15px !important;
// }
</style>
